# NUITRCS GitHub Actions Workshop
This repository is inspired by the [PyPA sampleproject](https://github.com/pypa/sampleproject).

# Documentation URL
[Documentation](https://nuitrcs.github.io/rcds-gh-actions-workshop/)
